==> echopop-0.4.1.tar.gz: echopop-0.4.1/README.md <==
# Echopop

Echopop combines acoustic data collected by echosounders with biological "ground truth" information from trawls to produce biological estimates, such as biomass and abundance. Here, "pop" stands for the animal "population."

Current the processing is configured to work with Acoustic-Trawl survey data for Pacific hake, but we will soon add components to include Pacific krill into the package. The majority of the computational implementation is applicable for other fish and zooplankton species, and we plan to expand the package for general support in the near future.


## Documentation

Learn more about Echopop in the documentation at https://echopop.readthedocs.io.


## Contributors

Echopop development is currently co-led by Wu-Jung Lee (@leewujung) and Brandyn Lucca (@brandynluca). Brandon Reyes (@b-reyes) and Emilio Mayorga (@emiliom) contributed significantly to a previous version of Echopop.



## Acknowledgement

We thank Dezhang Chu (@DezhangChu) of the NOAA Northwest Fisheries Science Center (NWFSC)
for providing the Matlab EchoPro program he developed
that many elements of Echopop is based on,
as well as his detailed consultation for implementations specific to Pacific hake.

We thank Rebecca Thomas (@rebeccathomas-NOAA),
Beth Phillips (@ElizabethMPhillips),
Alicia Billings (@aliciabillings-noaa),
and Julia Clemons (@JuliaClemons-NOAA)
of the NWFSC Fisheries Engineering and Acoustics Team (FEAT)
for continuing discussions that make Echopop better.

This project is supported by NOAA Fisheries.

<img src="docs/images/noaa_fisheries_logo.png" alt="NOAA_fisheries_logo" width="200">


## License

Echopop is licensed under the open source [Apache 2.0 license](https://opensource.org/licenses/Apache-2.0).

---------------

Copyright (c) 2022-2024, Echopop Developers.

==> echopop-0.4.2.tar.gz: echopop-0.4.2/README.md <==
<div>
  <a href="https://doi.org/10.5281/zenodo.11454148">
    <img src="https://zenodo.org/badge/DOI/10.5281/zenodo.11454148.svg" alt="DOI">
  </a>
  <a href="https://raw.githubusercontent.com/OSOceanAcoustics/echopop/master/LICENSE">
    <img alt="GitHub License" src="https://img.shields.io/github/license/OSOceanAcoustics/echopop">
  </a>
</div>

<div>
  <a href="https://echopop.readthedocs.io/en/latest/?badge=latest">
    <img src="https://readthedocs.org/projects/echopop/badge/?version=latest"/>
  </a>
</div>

<div>
  <a href="https://pypi.org/project/echopop/">
    <img src="https://img.shields.io/pypi/v/echopop.svg"/>
  </a>
  <a href="https://anaconda.org/conda-forge/echopop">
    <img src="https://img.shields.io/conda/vn/conda-forge/echopop.svg"/>
  </a>
</div>


# Echopop

Echopop combines acoustic data collected by echosounders with biological "ground truth" information from trawls to produce biological estimates, such as biomass and abundance. Here, "pop" stands for the animal "population."

Current the processing is configured to work with Acoustic-Trawl survey data for Pacific hake, but we will soon add components to include Pacific krill into the package. The majority of the computational implementation is applicable for other fish and zooplankton species, and we plan to expand the package for general support in the near future.


## Documentation

Learn more about Echopop in the documentation at https://echopop.readthedocs.io.


## Contributors

Echopop development is currently co-led by Wu-Jung Lee (@leewujung) and Brandyn Lucca (@brandynlucca). Brandon Reyes (@b-reyes) and Emilio Mayorga (@emiliom) contributed to a previous version of Echopop.



## Acknowledgement

We thank Dezhang Chu (@DezhangChu) of the NOAA Northwest Fisheries Science Center (NWFSC)
for providing the Matlab EchoPro program he developed
that many elements of Echopop is based on,
as well as his detailed consultation for implementations specific to Pacific hake.

We thank Rebecca Thomas (@rebeccathomas-NOAA),
Beth Phillips (@ElizabethMPhillips),
Alicia Billings (@aliciabillings-noaa),
and Julia Clemons (@JuliaClemons-NOAA)
of the NWFSC Fisheries Engineering and Acoustics Team (FEAT)
for continuing discussions that make Echopop better.

This project is supported by NOAA Fisheries.

<img src="docs/images/noaa_fisheries_logo.png" alt="NOAA_fisheries_logo" width="200">


## License

Echopop is licensed under the open source [Apache 2.0 license](https://opensource.org/licenses/Apache-2.0).

---------------

Copyright (c) 2022-2024, Echopop Developers.
